import Flutter
import UIKit

public class SwiftWatermarkShareablePlugin: NSObject, FlutterPlugin {
    var controller: UIViewController!
    var globalResult: FlutterResult!
    
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "watermark_shareable", binaryMessenger: registrar.messenger())
        let instance = SwiftWatermarkShareablePlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        controller = UIApplication.shared.keyWindow?.rootViewController
        globalResult = result
        switch(call.method) {
        case "getPostWithWaterMark":
            if let args = call.arguments as? Dictionary<String, String> {
                guard let image = args["image"],
                    let imageFile: String = image else { return }
                guard let type: String = args["type"],
                    let typeImage: String = type else { return }
                result(getPostWithWaterMark(imageFile: imageFile, type: typeImage))
            }
            break
        default:
            break
        }
        result("iOS " + UIDevice.current.systemVersion)
    }
    
    func getPostWithWaterMark(imageFile: String, type: String) -> Data? {
        guard let image = UIImage(contentsOfFile: imageFile) else { return nil }
        let resultImg = self.drawOnImage(image: image, type: type)
        return resultImg
    }
    
    func drawOnImage(image: UIImage, type: String) -> Data {
        
        UIGraphicsBeginImageContext(image.size)
        
        image.draw(at: CGPoint.zero)
        let img2 = UIImage(named: type)
        let rect = CGRect(x: 0, y: 0, width: image.size.width, height: image.size.height)
        
        UIGraphicsBeginImageContextWithOptions(image.size, true, 0)
        
        image.draw(in: rect, blendMode: .normal, alpha: 1)
        img2!.draw(in: rect, blendMode: .normal, alpha: 1)
        let myImage = UIGraphicsGetImageFromCurrentImageContext()
        UIGraphicsEndImageContext()
        let data = myImage?.pngData()
        return data!
    }
    
    
}


